@@ -1,7 +1,7 @@
 import numpy as np
 import numpy.linalg as la
 
-__version__ = '2.0.1'
+__version__ = '2.1.0'
 
 
 class LsqEllipse:
@@ -141,24 +141,24 @@ class LsqEllipse:
         g = self.coefficients[5]
 
         # Finding center of ellipse [eqn.19 and 20] from (**)
-        x0 = (c*d - b*f) / (b**2. - a*c)
-        y0 = (a*f - b*d) / (b**2. - a*c)
+        x0 = (c*d - b*f) / (b**2 - a*c)
+        y0 = (a*f - b*d) / (b**2 - a*c)
         center = [x0, y0]
 
         # Find the semi-axes lengths [eqn. 21 and 22] from (**)
         numerator = 2 * (a*f**2 + c*d**2 + g*b**2 - 2*b*d*f - a*c*g)
-        denominator1 = (b * b - a * c) * (
-            (c - a) * np.sqrt(1 + 4*b*b / ((a - c)*(a - c))) - (c + a)
+        denominator1 = (b*b - a*c) * (
+            (c-a) * np.sqrt(1+4*b**2 / ((a-c)*(a-c))) - (c+a)
         )
         denominator2 = (b*b - a*c) * (
-            (a - c) * np.sqrt(1 + 4*b*b / ((a - c) * (a - c))) - (c + a)
+            (a-c) * np.sqrt(1+4*b**2 / ((a-c) * (a-c))) - (c+a)
         )
         width = np.sqrt(numerator / denominator1)
         height = np.sqrt(numerator / denominator2)
 
         # Angle of counterclockwise rotation of major-axis of ellipse to x-axis
         # [eqn. 23] from (**) or [eqn. 26] from (***).
-        phi = .5 * np.arctan((2.*b) / (a - c))
+        phi = .5 * np.arctan((2.*b) / (a-c))
 
         return center, width, height, phi
 
@@ -189,7 +189,7 @@ class LsqEllipse:
                                  "provided")
 
         if t is None:
-            t = np.linspace(0, 2 * np.pi, n_points)
+            t = np.linspace(0, 2*np.pi, n_points)
 
         center, width, height, phi = self.as_parameters()
 
